# App Fiddle

<details markdown>

&nbsp;

<summary>Welcome to the Flask/SQLAlchemy "App Fiddle"</summary>

You've perhaps used JS Fiddle to explore JavaScript and HTML.  With the power of Codespaces, we can now provide a "fiddle" for a *complete application.*

Use this ***Application Fiddle*** to learn Flask/SQLAlchemy in Codespaces.  You have 4 running apps - execute them, explore the code, alter them (e.g., create endpoints, issue queries), use the debugger, etc.

These projects all use the [Northwind Sample Database](https://apilogicserver.github.io/Docs/Sample-Database/).  Other databases are also provided in Next Steps.

Start with the first application (`0. App_Fiddle`)- a basic, hand-coded Flask/SQLAlchemy App.

Then, discover **API Logic Server** - an Open Source CLI to create executable projects, **instantly,** with a single command.  Projects are **fully customizable** in your IDE, using both standard code, and unique spreadsheet like **rules** for logic and security - 40X more concise than manual code.

The Key Technology Concepts (at end) is an inventory of essential skills for creating Flask/SQLAlchemy systems.  Each are illustrated here.

</details>

&nbsp;

<details markdown>

&nbsp;



